@@ -252,6 +252,7 @@ def chk_is_valid_node(node_ids, node_name, node_conditions, nodes):
     df_valid_nodes = df_valid_nodes.drop('Type', 1)
     return df_valid_nodes
 
+
 def extract_dialog_stack(payload):
     res = []
     if 'main skill' in payload:
@@ -260,6 +261,25 @@ def extract_dialog_stack(payload):
                 res = json.loads(base64.b64decode(payload['main skill']['system']['state']))['dialog_stack']
     return res
 
+
+def extract_intent_started(payload):
+    res = None
+    if 'main skill' in payload:
+        if 'user_defined' in payload['main skill']:
+            if 'response_context_IntentStarted' in payload['main skill']['user_defined']:
+                res = payload['main skill']['user_defined']['response_context_IntentStarted']
+    return res
+
+
+def extract_intent_completed(payload):
+    res = None
+    if 'main skill' in payload:
+        if 'user_defined' in payload['main skill']:
+            if 'response_context_IntentCompleted' in payload['main skill']['user_defined']:
+                res = payload['main skill']['user_defined']['response_context_IntentCompleted']
+    return res
+
+
 def format_data(df):
     """This function formats the log data from watson assistant by separating columns and changing datatypes
        Parameters
@@ -270,7 +290,6 @@ def format_data(df):
        ----------
        df6 : Dataframe formatted by separating columns and changing datatypes
     """
-
     if len(df) == 0:
         print('No logs found, please check your data')
         return None
@@ -289,6 +308,7 @@ def format_data(df):
                      df1['response_context'].apply(pd.Series).add_prefix('response_context_'),
                      pd.DataFrame(df1['response_output'].tolist()).add_prefix('response_')],
                     axis=1)  # type: pd.DataFrame
+    
     # Add context_system fields
     df3 = pd.concat([df2.drop(['response_context_system'], axis=1),
                      df2['response_context_system'].apply(pd.Series).add_prefix('response_')],
@@ -297,6 +317,8 @@ def format_data(df):
     if 'response_context_skills' in df3:
         df3['response_context_skills'] = df3['response_context_skills'].fillna({i: {} for i in df3.index})
         df3['response_dialog_stack'] = df3['response_context_skills'].apply(lambda x: extract_dialog_stack(x))
+        df3['response_context_response_context_IntentStarted'] = df3['response_context_skills'].apply(lambda x: extract_intent_started(x))
+        df3['response_context_response_context_IntentCompleted'] = df3['response_context_skills'].apply(lambda x: extract_intent_completed(x))
 
     if 'response_context_response_context_IntentStarted' in df3.columns \
             and 'response_context_response_context_IntentCompleted' in df3.columns:
